@@ -7,12 +7,6 @@ module.exports = function(grunt) {
 				'stderr': true,
 				'failOnError': true
 			},
-			'cover-html': {
-				'command': 'istanbul cover --report "html" --verbose --dir "coverage" "tests/tests.js"'
-			},
-			'cover-coveralls': {
-				'command': 'istanbul cover --verbose --dir "coverage" "tests/tests.js" && coveralls < coverage/lcov.info; rm -rf -- coverage/lcov*'
-			},
 			'test-narwhal': {
 				'command': 'echo "Testing in Narwhal..."; export NARWHAL_OPTIMIZATION=-1; narwhal "tests/tests.js"'
 			},
@@ -41,14 +35,12 @@ module.exports = function(grunt) {
 
 	grunt.loadNpmTasks('grunt-shell');
 
-	grunt.registerTask('cover', 'shell:cover-html');
 	grunt.registerTask('ci', [
 		'shell:test-narwhal',
 		'shell:test-phantomjs',
 		'shell:test-rhino',
 		'shell:test-ringo',
-		'shell:test-node',
-		'shell:cover-html'
+		'shell:test-node'
 	]);
 	grunt.registerTask('test', [
 		'ci',
@@ -56,8 +48,7 @@ module.exports = function(grunt) {
 	]);
 
 	grunt.registerTask('default', [
-		'shell:test-node',
-		'cover'
+		'shell:test-node'
 	]);
 
 };
